==> telegram_client-0.5.16.tar.gz: bin/tg_client_test.dart <==
import 'dart:convert';

import 'package:galaxeus_lib/galaxeus_lib.dart' as glx_lib;
import 'package:telegram_client/telegram_client/telegram_client.dart';
import 'package:universal_io/io.dart';

void main(List<String> args) async {
  print("RUN");
  glx_lib.EventEmitter eventEmitter = glx_lib.EventEmitter();
  TelegramClientLib telegramClientLib = TelegramClientLib(
    eventEmitter: eventEmitter,
  );
  await telegramClientLib.init(
    telegramClientTdlibOption: TelegramClientTdlibOption(
      isAutoGetChat: false,
      is_cli: true,
      timeOutUpdate: 1.0,
      delayInvoke: Duration(milliseconds: 1),
      delayUpdate: Duration(milliseconds: 1),
      isInvokeThrowOnError: false,
    ),
    telegramClientTelegramBotApiOption: TelegramClientTelegramBotApiOption(
      clientOption: {},
    ),
  );
  // ignore: unused_local_variable
  TelegramClient tg = TelegramClient(
    telegram_client_lib: telegramClientLib,
  );

  // tg.telegram_client_lib.tdlib.on(tg.telegram_client_lib.tdlib.event_update, (update) => print(update.raw));
  tg.on(
    event_name: tg.telegram_client_lib.event_update,
    onUpdate: (updateTelegramClient) async {
      if (updateTelegramClient.telegramClientData.telegramClientType ==
          TelegramClientType.tdlib) {
        if (updateTelegramClient.rawData["@type"] == "updateNewMessage") {
          Map message = updateTelegramClient.rawData["message"];

          print(message.toStringifyPretty(2));
          // JsonScheme get_chat = await tg.request(parameters: {
          //   "@type": "getUser",
          //   "chat_id": chat_id,
          // }, telegramClientData: updateTelegramClient.telegramClientData);

          // print(get_chat.rawData.toStringifyPretty(2));
        }
      }
    },
    onError: () {},
  );

  await tg.telegram_client_lib.tdlib.initIsolate();

  stdin.listen((event) async {
    try {
      String command = utf8.decode(event).trim().toLowerCase();

      if (command == "login") {
        var res = await tg.invoke(
          parameters: {
            "@type": "checkAuthenticationBotToken",
            "token": "6532994758:",
          },
          telegramClientData: TelegramClientData(
            telegram_bot_api_token_bot: "",
            telegramClientType: TelegramClientType.tdlib,
            tdlib_client_id: 1,
          ),
        );
        print(res.rawData.toStringifyPretty(2));
      }
      if (command == "get_state") {
        var res = await tg.invoke(
          parameters: {
            "@type": "getAuthorizationState",
          },
          telegramClientData: TelegramClientData(
            telegram_bot_api_token_bot: "",
            telegramClientType: TelegramClientType.tdlib,
            tdlib_client_id: 1,
          ),
        );
        print(res.rawData.toStringifyPretty(2));
      }
    } catch (e) {
      print(e);
    }
  });
}

==> telegram_client-0.5.31.tar.gz: bin/tg_client_test.dart <==
import 'dart:convert';

import 'package:galaxeus_lib/galaxeus_lib.dart';
import 'package:telegram_client/telegram_client.dart';
import 'package:universal_io/io.dart';

void main(List<String> args) async {
  print("RUN");

  /// ignore: unused_local_variable
  TelegramClient tg = TelegramClient();

  tg.on(
    event_name: tg.event_update,
    onUpdate: (UpdateTelegramClient updateTelegramClient) async {
      if (updateTelegramClient.telegramClientData.telegramClientType ==
          TelegramClientType.tdlib) {
        if (updateTelegramClient.rawData["@type"] == "updateConnectionState") {
          var res = await updateTelegramClient.tg.invoke(
            parameters: {
              "@type": "getAuthorizationState",
            },
            telegramClientData: updateTelegramClient.telegramClientData,
          );
          print(res.rawData.toStringifyPretty(2));
        }

        // ignore: unused_local_variable
        Map? update = await updateTelegramClient.update;
        if (updateTelegramClient.rawData["@type"] == "updateNewMessage") {
          Map message = updateTelegramClient.rawData["message"];

          print(message.toStringifyPretty(2));
        }
      }
    },
    onError: (error, stackTrace) {},
  );

  await tg.init(
    pathTdlib: TgUtils.pathTdlib(),
  );

  stdin.listen((event) async {
    try {
      String command = utf8.decode(event).trim().toLowerCase();

      if (command == "login") {
        var res = await tg.invoke(
          parameters: {
            "@type": "checkAuthenticationBotToken",
            "token": "6532994758:AASASLAslpalspalspaps",
          },
          telegramClientData: TelegramClientData(
            telegram_bot_api_token_bot: "",
            telegramClientType: TelegramClientType.tdlib,
            tdlib_client_id: 1,
          ),
        );
        print(res.rawData.toStringifyPretty(2));
      }
      if (command == "get_state") {
        var res = await tg.invoke(
          parameters: {
            "@type": "getAuthorizationState",
          },
          telegramClientData: TelegramClientData(
            telegram_bot_api_token_bot: "",
            telegramClientType: TelegramClientType.tdlib,
            tdlib_client_id: 1,
          ),
        );
        print(res.rawData.toStringifyPretty(2));
      }
    } catch (e) {
      print(e);
    }
  });
}
